==> jc-1.4.0.tar.gz: javax/swing/text/StyledEditorKit__24FontFamilyAction.h <==
// public class javax.swing.text.StyledEditorKit$FontFamilyAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class cb5e6859e8868911 javax_swing_text_StyledEditorKit__24FontFamilyAction
// @dep_class 269e09938263c482 javax_swing_text_StyledEditorKit__24StyledTextAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_StyledEditorKit__24StyledTextAction

#include "javax/swing/text/StyledEditorKit__24StyledTextAction.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24FontFamilyAction_H_
#define _JC_javax_swing_text_StyledEditorKit__24FontFamilyAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_refs	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$refs	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$nonrefs	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vmethods	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtable	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtype	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	javax_swing_text_StyledEditorKit__24StyledTextAction;
	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vmethods	javax_swing_text_StyledEditorKit__24FontFamilyAction;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_refs {
	struct _jc_java_lang_String$object	*family;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$refs {
    _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_refs	javax_swing_text_StyledEditorKit__24FontFamilyAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24FontFamilyAction;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object {
	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtype _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24FontFamilyAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24FontFamilyAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/StyledEditorKit__24FontFamilyAction.h <==
// public class javax.swing.text.StyledEditorKit$FontFamilyAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class cb5e6859e8868911 javax_swing_text_StyledEditorKit__24FontFamilyAction
// @dep_class 269e09938263c482 javax_swing_text_StyledEditorKit__24StyledTextAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_StyledEditorKit__24StyledTextAction

#include "javax/swing/text/StyledEditorKit__24StyledTextAction.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24FontFamilyAction_H_
#define _JC_javax_swing_text_StyledEditorKit__24FontFamilyAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_refs	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$refs	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$nonrefs	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vmethods	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtable	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtype	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	javax_swing_text_StyledEditorKit__24StyledTextAction;
	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vmethods	javax_swing_text_StyledEditorKit__24FontFamilyAction;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_refs {
	struct _jc_java_lang_String$object	*family;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$refs {
    _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_refs	javax_swing_text_StyledEditorKit__24FontFamilyAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24FontFamilyAction;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$object {
	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$vtype _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24FontFamilyAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24FontFamilyAction$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24FontFamilyAction_H_ */
